@@ -61,7 +61,8 @@ class AirflowExporter(abc.AbstractExporter):
         pass
 
     @staticmethod
-    def _export(cfg, env_name, mode, until, skip_tests, ignore_git):
+    def _export(cfg, env_name, mode, until, skip_tests, ignore_git,
+                lazy_import):
         """
         Copies the current source code to the target environment folder.
         The code along with the DAG declaration file can be copied to
@@ -69,7 +70,10 @@ class AirflowExporter(abc.AbstractExporter):
         """
         with Commander(workspace=env_name,
                        templates_path=('soopervisor', 'assets')) as e:
-            tasks, args = commons.load_tasks(cmdr=e, name=env_name, mode=mode)
+            tasks, args = commons.load_tasks(cmdr=e,
+                                             name=env_name,
+                                             mode=mode,
+                                             lazy_import=lazy_import)
 
             if not tasks:
                 raise CommanderStop(f'Loaded DAG in {mode!r} mode has no '
